@@ -3,7 +3,7 @@ import os
 
 from tqdm import tqdm
 
-from src.huffpress.generic import dec_to_bin, bin_to_dec, Mode
+from huffpress.generic import dec_to_bin, bin_to_dec, Mode
 
 
 def reverse_final_sequence(bstr, verbose=False):
@@ -74,7 +74,7 @@ def decompress_file(inp_file, outfile=None, verbose=False):
     return outfile
 
 
-def decompress(inp, verbose=False):
+def decompress(inp, outfile=None, verbose=False):
     if (not isinstance(inp, bytearray)) and (not isinstance(inp, str)):
         raise TypeError("input must be a string or bytes: "
                         "either a filename including path OR a compressed binary text.")
@@ -82,4 +82,4 @@ def decompress(inp, verbose=False):
         if isinstance(inp, bytearray):
             return decompress_string(inp, verbose=verbose)
         else:
-            return decompress_file(inp, verbose=verbose)
+            return decompress_file(inp, outfile=outfile, verbose=verbose)
